@@ -65,6 +65,7 @@ class Eaves:
         self.type_handlers = {
             str: lambda status: exec('self.current_status = status')
         }
+        self.fps_cap: float = 60.0
         self.clock = pygame.time.Clock()
         self.handlers_to_load: list[str] = []
         self.res: Optional[tuple[int, int]] = None
@@ -191,7 +192,7 @@ class Eaves:
             data = func(events)
             if data: self.type_handlers[_type](data)
 
-            self.clock.tick()
+            self.clock.tick(self.fps_cap)
 
             display.flip()
             display.update()
